%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% 
% This function reduces an audio file
%
% Input(s): Input audio file
%           Number of bins
%           Threshold that data below does not get stored
%                  
% Output(s): Array containing spectral content of audio file
%          
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function output = histogram(inputData,binNumber,threshold)

r                = abs(fftshift(fft(audioread(inputData))));
[matrixLength,y] = size(r);
binSize          = floor(matrixLength/binNumber); 
histogram_array  = [];

%handles multiple channels 
if y == 2
    r = (r(:,1)+r(:,2))/2 ; % Channels averaged to create mono output.
elseif y > 2
    error(['Error: File contains more than two channels of audio'...
    'or the matrix has been setup incorrectly and needs roation'...
    '(must be n*1 matrix).']);
end

i = 1;
j = 1;
while i < binNumber
    meanBinValue = mean(r(j:j+binSize));
    if meanBinValue <= threshold
        histogram_array(end+1) = 0;
    else
        histogram_array(end+1) = meanBinValue;
    end
   
    i = i + 1;
    j = j + binSize;
end

output = histogram_array; 
end